What is OiRA | OiRA

Topics

# What is OiRA

## New to OiRA?

Here is a short introduction to risk assessment and how OiRA can help you to manage it.

## What is risk assessment?

Risk assessment is the basis for successful safety and health management and the key to reducing work-related accidents and occupational diseases. If it is implemented well, it can improve workplace safety and health - and business performance in general.

Workers’ safety and health is protected in Europe through assessing and managing risks at work. Employers have a legal duty to ensure the safety and health of workers in every aspect related to work and to carry out a risk assessment. Every company must therefore conduct a risk assessment and draw up an action plan. In order to carry out an effective workplace risk assessment, all those involved require a clear understanding of:

- the legal context and concepts;
- the process used to assess the risks;
- the role to be played by the main actors involved in the process.

Workers and/or their representatives have the right to be consulted on arrangements to carry out and participate in the risk assessment.

You can find more information on risk assessment and the participation of workers and/or their representatives in the risk assessment process on the OiRA project website.

## What is OiRA?

OiRA stands for Online Interactive Risk Assessment. It is a web-based application that allows you to perform a safety and health risk assessment of your workplace.

## Who is OiRA for?

OiRA can be used by anyone for assessing safety and health-related risks that might exist in their workplace.

However, OiRA is designed to be of most value to smaller businesses. OiRA has been developed specifically to support them in assessing the risks at work and help them produce a documented risk assessment, including an action plan tailored to the establishment’s requirements.

## What do I have to do?

There are several steps to be completed in the OiRA risk assessment process:

- Preparation: some tools have profile questions that help you tailor the tool to the specifics of your establishment. When you answer the profile questions, the tool will adapt to your specific situation and will show you the modules that apply.

- Involvement: every risk assessment should be done with active involvement of the workers. The tool allows you to print out the full text of the risk assessment, or parts of it, in order to inform workers and get their feedback.

- Risk identification: OiRA will present a series of potential safety and health hazards or problems that could exist in your workplace. By answering the statements/questions with either yes or no, you state whether such hazards or problems are present. You can also decide to leave a question unanswered and put it on hold to be answered at a later stage.

- Evaluation: some tools ask you to prioritise the risks you have identified. There are different ways of doing so, which depend on decisions taken by our national OiRA partners/tool developers and their specific approach. Some tools also prioritise risks automatically in the background and you are able to overrule these priorities.

- Action plan: for each identified risk, the tool asks you to decide on one or more measures to eliminate or reduce the risk. Most tools will suggest some measures to you. You can also always choose to enter your own measures.

- Report: you are legally required to document your risk assessment. In the report section, you will find a variety of reports that will help you keep track of your risk assessment and follow up on the actions/measures that you have decided to implement to eliminate or mitigate the risks identified.

## How long will it take?

It’s impossible to say how long an assessment will take in general, as the tools differ according to sector and country.

However, you can spend whatever time you have available on an assessment and then return to it when convenient and pick up from the same point you left off.

## Why do I have to register?

The first thing you will be asked to do when you begin your first risk assessment is to create an OiRA account - this is a simple and quick process.

Registering allows you to simply log in at any time to continue previous assessments or start new ones.

If you are a registered user, you also have the option to obtain a printed, accurate and up-dated risk assessment at any time.

## Do I need to prepare?

You do not need any kind of specific preparation to start using the tool; however, you should take some time to think about who is going to carry out the risk assessment and how workers are going to be involved in the process.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More